@@ -2,6 +2,11 @@
 from PyObjCTools.TestSupport import *
 from CalendarStore import *
 
+try:
+    unicode
+except NameError:
+    unicode = str
+
 class TestCalCalendar (TestCase):
     def testConstants(self):
         self.assertIsInstance(CalCalendarTypeBirthday, unicode)
@@ -15,6 +20,8 @@ class TestCalCalendar (TestCase):
     def testConstants10_6(self):
         self.assertIsInstance(CalCalendarTypeExchange, unicode)
 
+    def testMethods(self):
+        self.assertResultIsBOOL(CalCalendar.isEditable)
 
 
 if __name__ == "__main__":
